# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List
from typing_extensions import TypeAlias

from .connection import Connection

__all__ = ["ConnectionListConnectionsResponse"]

ConnectionListConnectionsResponse: TypeAlias = List[Connection]
